@@ -9,7 +9,12 @@ from .lutils.lmove import FCORD, TCORD
 from .lutils import ldraw
 from .Cord import Cord
 from .Move import Move
-from .const import *
+from .const import LOSERSCHESS, WHITE, WHITEWON, BLACKWON, WON_NOMATERIAL, KING, \
+    SUICIDECHESS, ATOMICCHESS, WON_KINGEXPLODE, KINGOFTHEHILLCHESS, BLACK, DRAW, \
+    WON_KINGINCENTER, THREECHECKCHESS, WON_THREECHECK, WON_MATE, DRAW_STALEMATE, \
+    DRAW_INSUFFICIENT, DRAW_EQUALMATERIAL, WON_LESSMATERIAL, DRAW_REPITITION, \
+    DRAW_50MOVES, RUNNING, ENPASSANT, UNKNOWN_REASON
+
 from .lutils.bitboard import iterBits
 from .lutils.attack import getAttacks
 from pychess.Variants.suicide import pieceCount
@@ -19,27 +24,30 @@ from pychess.Variants.kingofthehill import testKingInCenter
 from pychess.Variants.threecheck import checkCount
 
 
-def getDestinationCords (board, cord):
+def getDestinationCords(board, cord):
     tcords = []
-    for move in lmovegen.genAllMoves (board.board):
+    for move in lmovegen.genAllMoves(board.board):
         if FCORD(move) == cord.cord:
             if not board.board.willLeaveInCheck(move):
                 tcords.append(Cord(TCORD(move)))
     return tcords
 
-def isClaimableDraw (board):
+
+def isClaimableDraw(board):
     lboard = board.board
-    if lboard.repetitionCount () >= 3:
+    if lboard.repetitionCount() >= 3:
         return True
-    if ldraw.testFifty (lboard):
+    if ldraw.testFifty(lboard):
         return True
     return False
 
-def playerHasMatingMaterial (board, playercolor):
+
+def playerHasMatingMaterial(board, playercolor):
     lboard = board.board
     return ldraw.testPlayerMatingMaterial(lboard, playercolor)
 
-def getStatus (board):
+
+def getStatus(board):
     lboard = board.board
 
     if board.variant == LOSERSCHESS:
@@ -78,13 +86,14 @@ def getStatus (board):
                 status = BLACKWON
             return status, WON_THREECHECK
     else:
-        if ldraw.testMaterial (lboard):
+        if ldraw.testMaterial(lboard):
             return DRAW, DRAW_INSUFFICIENT
-    
+
     hasMove = False
-    for move in lmovegen.genAllMoves (lboard):
+    for move in lmovegen.genAllMoves(lboard):
         if board.variant == ATOMICCHESS:
-            if kingExplode(lboard, move, 1-board.color) and not kingExplode(lboard, move, board.color):
+            if kingExplode(lboard, move, 1 - board.color) and not kingExplode(
+                    lboard, move, board.color):
                 hasMove = True
                 break
             elif kingExplode(lboard, move, board.color):
@@ -121,7 +130,8 @@ def getStatus (board):
                 if pieceCount(lboard, WHITE) == pieceCount(lboard, BLACK):
                     return status, DRAW_EQUALMATERIAL
                 else:
-                    if board.color == WHITE and pieceCount(lboard, WHITE) < pieceCount(lboard, BLACK):
+                    if board.color == WHITE and pieceCount(
+                            lboard, WHITE) < pieceCount(lboard, BLACK):
                         status = WHITEWON
                     else:
                         status = BLACKWON
@@ -129,26 +139,28 @@ def getStatus (board):
             else:
                 return DRAW, DRAW_STALEMATE
 
-    if lboard.repetitionCount () >= 3:
+    if lboard.repetitionCount() >= 3:
         return DRAW, DRAW_REPITITION
-    
-    if ldraw.testFifty (lboard):
+
+    if ldraw.testFifty(lboard):
         return DRAW, DRAW_50MOVES
 
     return RUNNING, UNKNOWN_REASON
-    
-def standard_validate (board, move):
-    return validateMove (board.board, move.move) and \
-           not board.board.willLeaveInCheck(move.move)
 
-def validate (board, move):
+
+def standard_validate(board, move):
+    return validateMove(board.board, move.move) and \
+        not board.board.willLeaveInCheck(move.move)
+
+
+def validate(board, move):
     if board.variant == LOSERSCHESS:
-        capture = move.flag == ENPASSANT or board[move.cord1] != None
+        capture = move.flag == ENPASSANT or board[move.cord1] is not None
         if capture:
-            return standard_validate (board, move)
+            return standard_validate(board, move)
         else:
             can_capture = False
-            can_escape_with_capture= False
+            can_escape_with_capture = False
             ischecked = board.board.isChecked()
             for c in lmovegen.genCaptures(board.board):
                 if board.board.willLeaveInCheck(c):
@@ -160,55 +172,57 @@ def validate (board, move):
                     break
             if can_capture:
                 if ischecked and not can_escape_with_capture:
-                    return standard_validate (board, move)
+                    return standard_validate(board, move)
                 else:
                     return False
             else:
-                return standard_validate (board, move)
+                return standard_validate(board, move)
     elif board.variant == SUICIDECHESS:
-        capture = move.flag == ENPASSANT or board[move.cord1] != None
+        capture = move.flag == ENPASSANT or board[move.cord1] is not None
         if capture:
-            return standard_validate (board, move)
+            return standard_validate(board, move)
         else:
             can_capture = False
             for c in lmovegen.genCaptures(board.board):
-                from pychess.Utils.Move import Move
                 can_capture = True
-                #break
             if can_capture:
                 return False
             else:
-                return standard_validate (board, move)
+                return standard_validate(board, move)
     elif board.variant == ATOMICCHESS:
         # Moves exploding our king are not allowed
         if kingExplode(board.board, move.move, board.color):
             return False
         # Exploding oppont king takes precedence over mate
-        elif kingExplode(board.board, move.move, 1-board.color) and validateMove(board.board, move.move):
+        elif kingExplode(board.board, move.move, 1 -
+                         board.color) and validateMove(board.board, move.move):
             return True
         else:
-            return standard_validate (board, move)
+            return standard_validate(board, move)
     else:
-        return standard_validate (board, move)
+        return standard_validate(board, move)
 
-def getMoveKillingKing (board):
+
+def getMoveKillingKing(board):
     """ Returns a move from the current color, able to capture the opponent
         king """
-    
+
     lboard = board.board
     color = lboard.color
-    opking = lboard.kings[1-color]
-    
-    for cord in iterBits (getAttacks(lboard, opking, color)):
+    opking = lboard.kings[1 - color]
+
+    for cord in iterBits(getAttacks(lboard, opking, color)):
         return Move(Cord(cord), Cord(opking), board)
 
-def genCastles (board):
+
+def genCastles(board):
     for move in lmovegen.genCastles(board.board):
         yield Move(move)
 
-def legalMoveCount (board):
+
+def legalMoveCount(board):
     moves = 0
-    for move in lmovegen.genAllMoves (board.board):
+    for move in lmovegen.genAllMoves(board.board):
         if not board.board.willLeaveInCheck(move):
             moves += 1
     return moves
