@@ -10,7 +10,10 @@ from pychess.compat import unicode
 from pychess.ic.FICSObjects import make_sensitive_if_available, make_sensitive_if_playing
 from pychess.ic.ICGameModel import ICGameModel
 from pychess.Utils.Offer import Offer
-from pychess.Utils.const import *
+from pychess.Utils.const import WAITING_TO_START, MENU_ITEMS, WHITE, BLACK, WHITEWON, \
+    BLACKWON, WON_ADJUDICATION, TAKEBACK_OFFER, LOCAL, UNDOABLE_STATES, WHITE_ENGINE_DIED, \
+    UNDOABLE_REASONS, BLACK_ENGINE_DIED, HINT, SPY, RUNNING, ABORT_OFFER, ADJOURN_OFFER, \
+    DRAW_OFFER, PAUSE_OFFER, RESUME_OFFER, HURRY_ACTION
 from pychess.Utils.repr import reprResult_long, reprReason_long
 from pychess.System import conf
 from pychess.System.idle_add import idle_add
@@ -21,13 +24,14 @@ from pychess.widgets import InfoBar
 
 from .gamewidget import getWidgets, key2gmwidg, isDesignGWShown
 
-def nurseGame (gmwidg, gamemodel):
+
+def nurseGame(gmwidg, gamemodel):
     """ Call this function when gmwidget is just created """
     log.debug("nurseGame: %s %s" % (gmwidg, gamemodel))
     gmwidg.connect("infront", on_gmwidg_infront)
     gmwidg.connect("closed", on_gmwidg_closed)
     gmwidg.connect("title_changed", on_gmwidg_title_changed)
-    
+
     # Because of the async loading of games, the game might already be started,
     # when nurseGame is called.
     # Thus we support both cases.
@@ -38,7 +42,7 @@ def nurseGame (gmwidg, gamemodel):
         if gamemodel.uri:
             game_loaded(gamemodel, gamemodel.uri, gmwidg)
         on_game_started(gamemodel, gmwidg)
-    
+
     gamemodel.connect("game_saved", game_saved, gmwidg)
     gamemodel.connect("game_ended", game_ended, gmwidg)
     gamemodel.connect("game_unended", game_unended, gmwidg)
@@ -49,19 +53,23 @@ def nurseGame (gmwidg, gamemodel):
     if isinstance(gamemodel, ICGameModel):
         gamemodel.connection.connect("disconnected", on_disconnected, gmwidg)
 
-def on_disconnected (fics_connection, gamewidget):
+
+def on_disconnected(fics_connection, gamewidget):
     @idle_add
     def disable_buttons():
-        for b in gamewidget.game_ended_message.buttons:
-            b.set_property("sensitive", False)
-            b.set_property("tooltip-text", "")
+        for button in gamewidget.game_ended_message.buttons:
+            button.set_property("sensitive", False)
+            button.set_property("tooltip-text", "")
+
     if gamewidget.game_ended_message:
         disable_buttons()
-#===============================================================================
+
+
+# ===============================================================================
 # Gamewidget signals
-#===============================================================================
+# ===============================================================================
 @idle_add
-def on_gmwidg_infront (gmwidg):
+def on_gmwidg_infront(gmwidg):
     for widget in MENU_ITEMS:
         if widget in gmwidg.menuitems:
             continue
@@ -69,34 +77,36 @@ def on_gmwidg_infront (gmwidg):
             getWidgets()[widget].set_property('sensitive', False)
         else:
             getWidgets()[widget].set_property('sensitive', True)
-    
+
     # Change window title
     getWidgets()['window1'].set_title('%s - PyChess' % gmwidg.display_text)
     return False
 
+
 @idle_add
-def on_gmwidg_closed (gmwidg):
+def on_gmwidg_closed(gmwidg):
     if len(key2gmwidg) == 1:
         getWidgets()['window1'].set_title('%s - PyChess' % _('Welcome'))
     return False
 
 
 @idle_add
-def on_gmwidg_title_changed (gmwidg, new_title):
-    #log.debug("gamenanny.on_gmwidg_title_changed: starting %s" % repr(gmwidg))
+def on_gmwidg_title_changed(gmwidg, new_title):
+    # log.debug("gamenanny.on_gmwidg_title_changed: starting %s" % repr(gmwidg))
     if gmwidg.isInFront():
         getWidgets()['window1'].set_title('%s - PyChess' % new_title)
-    #log.debug("gamenanny.on_gmwidg_title_changed: returning")
+    # log.debug("gamenanny.on_gmwidg_title_changed: returning")
     return False
 
-#===============================================================================
+# ===============================================================================
 # Gamemodel signals
-#===============================================================================
+# ===============================================================================
+
 
 @idle_add
-def game_ended (gamemodel, reason, gmwidg):
-    log.debug("gamenanny.game_ended: reason=%s gmwidg=%s\ngamemodel=%s" % \
-        (reason, gmwidg, gamemodel))
+def game_ended(gamemodel, reason, gmwidg):
+    log.debug("gamenanny.game_ended: reason=%s gmwidg=%s\ngamemodel=%s" %
+              (reason, gmwidg, gamemodel))
     nameDic = {"white": gamemodel.players[WHITE],
                "black": gamemodel.players[BLACK],
                "mover": gamemodel.curplayer}
@@ -106,24 +116,26 @@ def game_ended (gamemodel, reason, gmwidg):
     elif gamemodel.status == BLACKWON:
         nameDic["winner"] = gamemodel.players[BLACK]
         nameDic["loser"] = gamemodel.players[WHITE]
-    m1 = reprResult_long[gamemodel.status] % nameDic
-    m2 = reprReason_long[reason] % nameDic
+    msg_one = reprResult_long[gamemodel.status] % nameDic
+    msg_two = reprReason_long[reason] % nameDic
     if gamemodel.reason == WON_ADJUDICATION:
         color = BLACK if gamemodel.status == WHITEWON else WHITE
         invalid_move = gamemodel.players[color].invalid_move
         if invalid_move:
-            m2 += _(" invalid engine move: %s" % invalid_move)
+            msg_two += _(" invalid engine move: %s" % invalid_move)
 
-    content = InfoBar.get_message_content(m1, m2, Gtk.STOCK_DIALOG_INFO)
+    content = InfoBar.get_message_content(msg_one, msg_two, Gtk.STOCK_DIALOG_INFO)
     message = InfoBarMessage(Gtk.MessageType.INFO, content, None)
 
     callback = None
     if isinstance(gamemodel, ICGameModel):
         if gamemodel.hasLocalPlayer() and not gamemodel.examined:
-            def status_changed (player, prop, message):
+
+            def status_changed(player, prop, message):
                 make_sensitive_if_available(message.buttons[0], player)
                 make_sensitive_if_playing(message.buttons[1], player)
-            def callback (infobar, response, message):
+
+            def callback(infobar, response, message):
                 if response == 0:
                     gamemodel.remote_player.offerRematch()
                 elif response == 1:
@@ -137,48 +149,55 @@ def game_ended (gamemodel, reason, gmwidg):
             status_changed(gamemodel.remote_ficsplayer, None, message)
 
         else:
-            def status_changed (player, prop, button):
+
+            def status_changed(player, prop, button):
                 make_sensitive_if_playing(button, player)
-            def callback (infobar, response, message):
+
+            def callback(infobar, response, message):
                 if response in (0, 1):
                     gamemodel.players[response].observe()
                 return False
-            for i, p in enumerate(gamemodel.ficsplayers):
-                b = InfoBarMessageButton(_("Observe %s" % p.name), i)
-                message.add_button(b)
-                gmwidg.cids[p] = p.connect("notify::status", status_changed, b)
-                status_changed(p, None, b)
+
+            for i, player in enumerate(gamemodel.ficsplayers):
+                button = InfoBarMessageButton(_("Observe %s" % player.name), i)
+                message.add_button(button)
+                gmwidg.cids[player] = player.connect("notify::status", status_changed, button)
+                status_changed(player, None, button)
 
     elif gamemodel.hasLocalPlayer():
-        def callback (infobar, response, message):
+
+        def callback(infobar, response, message):
             if response == 1:
                 # newGameDialog uses ionest uses gamenanny uses newGameDialog...
                 from pychess.widgets.newGameDialog import createRematch
                 createRematch(gamemodel)
             elif response == 2:
                 if gamemodel.ply > 1:
-                    offer = Offer(TAKEBACK_OFFER, gamemodel.ply-2)
+                    offer = Offer(TAKEBACK_OFFER, gamemodel.ply - 2)
                 else:
-                    offer = Offer(TAKEBACK_OFFER, gamemodel.ply-1)
+                    offer = Offer(TAKEBACK_OFFER, gamemodel.ply - 1)
                 if gamemodel.players[0].__type__ == LOCAL:
                     gamemodel.players[0].emit("offer", offer)
-                else: gamemodel.players[1].emit("offer", offer)
+                else:
+                    gamemodel.players[1].emit("offer", offer)
             return False
+
         if not gamemodel.isLoadedGame():
             message.add_button(InfoBarMessageButton(_("Play Rematch"), 1))
         if gamemodel.status in UNDOABLE_STATES and gamemodel.reason in UNDOABLE_REASONS:
             if gamemodel.ply == 1:
                 message.add_button(InfoBarMessageButton(_("Undo one move"), 2))
             elif gamemodel.ply > 1:
-                message.add_button(InfoBarMessageButton(_("Undo two moves"), 2))
+                message.add_button(InfoBarMessageButton(
+                    _("Undo two moves"), 2))
 
     message.callback = callback
     gmwidg.game_ended_message = message
 
     if len(key2gmwidg) > 0:
         gmwidg.replaceMessages(message)
-        gmwidg.status("%s %s." % (m1,m2[0].lower()+m2[1:]))
-    
+        gmwidg.status("%s %s." % (msg_one, msg_two[0].lower() + msg_two[1:]))
+
     if reason == WHITE_ENGINE_DIED:
         engineDead(gamemodel.players[0], gmwidg)
     elif reason == BLACK_ENGINE_DIED:
@@ -192,48 +211,57 @@ def game_ended (gamemodel, reason, gmwidg):
             gamemodel.pause_analyzer(HINT)
         if not conf.get("spy_mode", False):
             gamemodel.pause_analyzer(SPY)
-    
+
     return False
 
-def _set_statusbar (gamewidget, message):
+
+def _set_statusbar(gamewidget, message):
     assert isinstance(message, str) or isinstance(message, unicode)
     gamewidget.status(message)
-    
-def game_paused (gamemodel, gmwidg):
+
+
+def game_paused(gamemodel, gmwidg):
     s = _("The game is paused")
     _set_statusbar(gmwidg, s)
     return False
-    
-def game_changed (gamemodel, ply, gmwidg):
+
+
+def game_changed(gamemodel, ply, gmwidg):
     _set_statusbar(gmwidg, "")
     return False
 
+
 @idle_add
-def game_unended (gamemodel, gmwidg):
+def game_unended(gamemodel, gmwidg):
     log.debug("gamenanny.game_unended: %s" % gamemodel.boards[-1])
     gmwidg.clearMessages()
     _set_statusbar(gmwidg, "")
     return False
 
+
 # Connect game_loaded, game_saved and game_ended to statusbar
-def game_loaded (gamemodel, uri, gmwidg):
+def game_loaded(gamemodel, uri, gmwidg):
     if type(uri) in (str, unicode):
-        s = "%s: %s" % (_("Loaded game"), str(uri))
-    else: s = _("Loaded game")
-    
-    _set_statusbar(gmwidg, s)
+        str_out = "%s: %s" % (_("Loaded game"), str(uri))
+    else:
+        str_out = _("Loaded game")
+
+    _set_statusbar(gmwidg, str_out)
     return False
 
-def game_saved (gamemodel, uri, gmwidg):
+
+def game_saved(gamemodel, uri, gmwidg):
     _set_statusbar(gmwidg, "%s: %s" % (_("Saved game"), str(uri)))
     return False
 
-def analyzer_added (gamemodel, analyzer, analyzer_type, gmwidg):
-    s = _("Analyzer started") + ": " + analyzer.name
-    _set_statusbar(gmwidg, s)
+
+def analyzer_added(gamemodel, analyzer, analyzer_type, gmwidg):
+    str_out = _("Analyzer started") + ": " + analyzer.name
+    _set_statusbar(gmwidg, str_out)
     return False
 
-def on_game_started (gamemodel, gmwidg):
+
+def on_game_started(gamemodel, gmwidg):
     on_gmwidg_infront(gmwidg)  # setup menu items sensitivity
 
     # Rotate to human player
@@ -244,18 +272,18 @@ def on_game_started (gamemodel, gmwidg):
         elif conf.get("autoRotate", True) and \
                 gamemodel.curplayer == gamemodel.players[1]:
             boardview.rotation = math.pi
-    
+
     # Play set-up sound
     preferencesDialog.SoundTab.playAction("gameIsSetup")
-    
+
     # Connect player offers to statusbar
     for player in gamemodel.players:
         if player.__type__ == LOCAL:
             player.connect("offer", offer_callback, gamemodel, gmwidg)
-    
+
     # Start analyzers if any
     gamemodel.connect("analyzer_added", analyzer_added, gmwidg)
-    if not (isinstance(gamemodel, ICGameModel) and \
+    if not (isinstance(gamemodel, ICGameModel) and
             gamemodel.isObservationGame() is False) and \
        not gamemodel.isEngine2EngineGame():
         gamemodel.start_analyzer(HINT)
@@ -266,11 +294,12 @@ def on_game_started (gamemodel, gmwidg):
             gamemodel.pause_analyzer(SPY)
     return False
 
-#===============================================================================
+# ===============================================================================
 # Player signals
-#===============================================================================
+# ===============================================================================
 
-def offer_callback (player, offer, gamemodel, gmwidg):
+
+def offer_callback(player, offer, gamemodel, gmwidg):
     if gamemodel.status != RUNNING:
         # If the offer has already been handled by Gamemodel and the game was
         # drawn, we need to do nothing
@@ -291,18 +320,22 @@ def offer_callback (player, offer, gamemodel, gmwidg):
         message = _("You sent an undo offer")
     elif offer.type == HURRY_ACTION:
         message = _("You asked your opponent to move")
-    
+
     _set_statusbar(gmwidg, message)
     return False
 
-#===============================================================================
+# ===============================================================================
 # Subfunctions
-#===============================================================================
+# ===============================================================================
 
-def engineDead (engine, gmwidg):
+
+def engineDead(engine, gmwidg):
     gmwidg.bringToFront()
-    d = Gtk.MessageDialog(type=Gtk.MessageType.ERROR, buttons=Gtk.ButtonsType.OK)
-    d.set_markup(_("<big><b>Engine, %s, has died</b></big>") % repr(engine))
-    d.format_secondary_text(_("PyChess has lost connection to the engine, probably because it has died.\n\nYou can try to start a new game with the engine, or try to play against another one."))
-    d.connect("response", lambda d,r: d.hide())
-    d.show_all()
+    dialog = Gtk.MessageDialog(type=Gtk.MessageType.ERROR,
+                               buttons=Gtk.ButtonsType.OK)
+    dialog.set_markup(_("<big><b>Engine, %s, has died</b></big>") % repr(engine))
+    dialog.format_secondary_text(_(
+        "PyChess has lost connection to the engine, probably because it has died.\n\n \
+        You can try to start a new game with the engine, or try to play against another one."))
+    dialog.connect("response", lambda dialog, r: dialog.hide())
+    dialog.show_all()
